@@ -2,7 +2,6 @@ import os
 import re
 import json
 import gcsfs
-import requests
 
 from google.cloud import aiplatform, pubsub_v1
 
@@ -262,3 +261,18 @@ def check_file_exists(filepath):
         filepath = filepath.replace("gs://", "")
     gcs_file_system = gcsfs.GCSFileSystem()
     return gcs_file_system.exists(filepath)
+
+
+def get_dataset_id_from_model_id(model_id):
+    """
+    Returns the id of the dataset used to train the model with id 'model_id'.
+    ----------------
+    args:
+        model_id (str) : id of the model
+    returns:
+        dataset_id (str) : id of the dataset used to train the model
+    ----------------
+    """
+    model_data = read_json_from_gcp_storage(
+        file_path="captur-ml/models/model_dataset_mapping.json")
+    return model_data.get(model_id)
\ No newline at end of file
